import React, { useEffect, useState } from 'react';
import { FormattedMessage, useIntl } from 'react-intl';
import FormContainer from '../layout/form-container';
import Header from '../layout/header';
import Footer from '../layout/footer';
import { Link as RouterLink } from 'react-router-dom';
import Typography from '@mui/material/Typography';
import Button from '@mui/material/Button';
import ReactGA from 'react-ga4';
import Client from '../../classes/client';
import { useSelector } from 'react-redux';
import { activeInstance } from '../../redux/clientSlice';
import { useNavigate } from 'react-router-dom';
import { css } from '@emotion/react';
import { CircularProgress } from '@mui/material';
import GlobalError from '../form/global-error';

const RegistrationCallbackPage = (): React.ReactElement => {
  const intl = useIntl();
  const client: Client = useSelector(activeInstance);

  const [email, setEmail] = useState(undefined);
  const [syncCode, setSyncCode] = useState(undefined);
  const [googleSync, setGoogleSync] = useState(undefined);
  const [callbackError, setCallbackError] = useState(false);
  const navigate = useNavigate();

  useEffect(() => {
    document.title = intl.formatMessage({
      id: 'registation.success-title',
      defaultMessage: 'Registation Success | WiseMapping',
    });
    ReactGA.send({
      hitType: 'pageview',
      page: window.location.pathname,
      title: 'Registration:Success',
    });
  });

  useEffect(() => {
    const googleOauthCode = new URLSearchParams(window.location.search).get('code');
    client
      .processGoogleCallback(googleOauthCode)
      .then((result) => {
        if (result.googleSync) {
          // if service reports that user already has sync accounts, go to maps page
          navigate('/c/maps');
        }
        setEmail(result.email);
        setSyncCode(result.syncCode);
        setGoogleSync(result.googleSync);
      })
      .catch((error) => {
        console.log('ERROR', error);
        setCallbackError(true);
      });
  }, []);

  const confirmAccountSynching = () => {
    client
      .confirmAccountSync(email, syncCode)
      .then(() => {
        navigate('/c/maps');
      })
      .catch((error) => {
        console.log('ERROR', error);
      });
  };

  const buttonsStyle = css({
    marginLeft: '10px',
    marginRight: '10px',
  });

  // if service reports that user doesnt sync accounts yet, we need to show the options
  const needConfirmLinking = !callbackError && email && !googleSync;
  const titleKey = needConfirmLinking
    ? 'registration.callback.confirm.title'
    : 'registration.callback.waiting.title';
  const titleDefaultValue = needConfirmLinking ? 'Confirm' : 'Finishing...';
  const descriptionKey = needConfirmLinking
    ? 'registration.callback.confirm.description'
    : 'registration.callback.waiting.description';
  const descriptionDefaultValue = needConfirmLinking
    ? 'An account with the same email was previously registered. Do you want to link your google account to that WiseMapping account?'
    : 'Please wait while we validate your identity';

  return (
    <div>
      <Header type="none" />
      <FormContainer>
        <Typography variant="h4" component="h1">
          <FormattedMessage id={titleKey} defaultMessage={titleDefaultValue} />
        </Typography>
        <Typography paragraph>
          <FormattedMessage id={descriptionKey} defaultMessage={descriptionDefaultValue} />
        </Typography>

        {callbackError && (
          <>
            <GlobalError
              error={{
                msg: intl.formatMessage({
                  id: 'registation.callback.error.message',
                  defaultMessage:
                    'An error occurred validating your identity with Google, you can try again from the login page',
                }),
              }}
            />
            <Button
              color="primary"
              size="medium"
              variant="contained"
              component={RouterLink}
              to="/c/login"
              disableElevation={true}
              css={buttonsStyle}
            >
              <FormattedMessage id="registration.callback.back" defaultMessage="Back to login" />
            </Button>
          </>
        )}

        {!needConfirmLinking && !callbackError && <CircularProgress />}

        {needConfirmLinking && (
          <>
            <Button
              color="secondary"
              size="medium"
              variant="contained"
              component={RouterLink}
              to="/c/login"
              disableElevation={true}
              css={buttonsStyle}
            >
              <FormattedMessage id="registration.callback.back" defaultMessage="Back to login" />
            </Button>
            <Button
              onClick={() => {
                confirmAccountSynching();
              }}
              color="primary"
              size="medium"
              variant="contained"
              disableElevation={true}
              css={buttonsStyle}
            >
              <FormattedMessage id="registration.callback.sync" defaultMessage="Sync account" />
            </Button>
          </>
        )}
      </FormContainer>
      <Footer />
    </div>
  );
};

export default RegistrationCallbackPage;
